@@ -5,7 +5,7 @@ use warnings;
 package Mail::Message::TransferEnc::Binary;
 use base 'Mail::Message::TransferEnc';
 
-our $VERSION = 2.00_16;
+our $VERSION = 2.00_17;
 
 =head1 NAME
 
@@ -91,6 +91,7 @@ sub decode($@)
 
 sub encode($@)
 {   my ($self, $body, %args) = @_;
+
     my @lines;
 
     my $changes = 0;
@@ -104,7 +105,7 @@ sub encode($@)
         return $body;
     }
 
-    my $bodytype = $args{result_type} || ref $self;
+    my $bodytype = $args{result_type} || ref($self->load);
 
     $bodytype->new
      ( based_on          => $self
@@ -140,7 +141,7 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-This code is beta, version 2.00_16.
+This code is beta, version 2.00_17.
 
 Copyright (c) 2001 Mark Overmeer. All rights reserved.
 This program is free software; you can redistribute it and/or modify
